<?php
namespace Teknisa\CTB\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;

class Ger07700AuditoresIndependentesService {

  protected $nrorg;
  protected $environment;

  public function __construct(Environment $environment, EntityManager $entityManager) {
    $this->environment = $environment;
    $this->nrorg = $this->environment->getNrOrg();
    $this->connection = $entityManager->getConnection();
  }

  public function validateAuditor($row) {

    if (!array_key_exists('NMAUDITOR', $row) || !array_key_exists('DSREGISTROCVM', $row))
        throw new \Exception('Campos obrigatórios vazios!');
    if (ctype_space($row['NMAUDITOR']) || ctype_space($row['DSREGISTROCVM']))
        throw new \Exception('Campos obrigatórios vazios!');
    $cvmExists = $this->verificaCVMAuditor(array(
      "DSREGISTROCVM" => $row['DSREGISTROCVM'],
      "NRORG" => $this->nrorg
    ));
    if ($cvmExists && $row['__is_new']) {
        throw new \Exception("Este registro de CVM já está cadastrado.");
    }


  }

  public function validateRelacao($row) {
    if (!array_key_exists('CDEMPRESA', $row) || !array_key_exists('NRSEQAUDITOR', $row))
        throw new \Exception('Campos obrigatórios vazios!');
    if (ctype_space($row['CDEMPRESA']) || is_null($row['NRSEQAUDITOR']))
        throw new \Exception('Campos obrigatórios vazios!');
    $relacaoExists = $this->verificaRelacaoAudEmpresa(array(
      "CDEMPRESA" => $row['CDEMPRESA'],
      "NRSEQAUDITOR" => $row['NRSEQAUDITOR'],
      "NRORG" => $this->nrorg
    ));
    if ($relacaoExists) {
        throw new \Exception("O auditor independente selecionado já está relacionado a esta empresa.");
    }
  }

  public function verificaCVMAuditor($params) {
    $sql = "SELECT 1 FROM AUDINDEPENDENTE WHERE DSREGISTROCVM = :DSREGISTROCVM AND NRORG = :NRORG";
    $std = $this->connection->prepare($sql);
    $std->execute($params);
    return $std->fetch();
  }

  public function verificaRelacaoAudEmpresa($params) {
    $sql = "SELECT 1 FROM AUDINDEMPRESA WHERE CDEMPRESA = :CDEMPRESA AND NRSEQAUDITOR = :NRSEQAUDITOR AND NRORG = :NRORG ";
    $std = $this->connection->prepare($sql);
    $std->execute($params);
    return $std->fetch();
  }

}
