var Ctb13000_RecalculoSaldoFiscal_Controller = function(ScreenService, General) {

    // Armazena a máscar de conta contábil retornada da PARAMGERAL.
    var contctblMask;

    /*
     * Função chamada por máscaras dos campos de conta contábil.
     * Retorna a máscara de conta contábil setada previamente na variável.
     */
    this.getContctblMask = function() {
        return contctblMask;
    };

    this.recalcularSaldoFiscal = function(recalculoWidget) {
        // Verifica se todos os campos obrigatórios foram preenchidos.
        if (recalculoWidget.isValid()) {
            var currentRow = recalculoWidget.currentRow;
            // Verifica se a conta final é igual ou maior do que a conta inicial.
            if (currentRow.CDCONTCTBLFIN < currentRow.CDCONTCTBLINI) {
                ScreenService.showMessage("Conta inicial deve ser menor ou igual à conta final.");
                return;
            }

            // Verifica se a data final foi preenchida, setando o valor NULL caso contrário.
            currentRow.DTFINAL = currentRow.DTFINAL ? currentRow.DTFINAL : null;

            // Verifica se a data final foi preenchida e é igual ou maior do que a data inicial.
            if (currentRow.DTFINAL !== null && moment(currentRow.DTFINAL, 'DD/MM/YYYY').isBefore(moment(currentRow.DTINICIAL, 'DD/MM/YYYY'))) {
                ScreenService.showMessage("A Data Final, quando informada, deve ser maior ou igual à data inicial informada.");
                return;
            }

            // Muda a mensagem de carregamento para uma mensagem personalizada.
            ScreenService.changeLoadingMessage("Recalculando os saldos...");

            // Chama a rota para efetuar a rotina de recálculo.
            General.callRestEngine("ctb#/recalculoSaldoFiscal", "Row", currentRow)
            .then(function() {
                ScreenService.showMessage("O recálculo de saldo fiscal foi realizado com sucesso.");
            })
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';

                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }

                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            })
            .finally(function() {
                // Restaura a mensagem original.
                ScreenService.restoreDefaultLoadingMessage();
            });
        }
    };

    /*
     * Função chamada pela tela ao ser aberta.
     * Seta a máscara de conta contábil buscada da PARAMGERAL na variável.
     */
    this.setContctblMask = function() {
        // Chama a rota que retorna os dados da PARAMGERAL.
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            // Busca o primeiro dado retornado, que será o único registro da parametrização.
            var paramgeral = response.dataset.paramgeral[0];

            // Armazena o valor da máscara na variável.
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb13000_RecalculoSaldoFiscal_Controller', Ctb13000_RecalculoSaldoFiscal_Controller);
});